==> yagroup_pay-0.1.1.tar.gz: yagroup_pay-0.1.1/yagroup_pay/routers/method.py <==
#
# (c) 2025, Yegor Yakubovich, yegoryakubovich.com, personal@yegoryakybovich.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from nexium_api import route

from services import MethodFacadeService
from shared import CreateMethodRequestData, CreateMethodResponseData, GetMethodsRequestData, GetMethodsResponseData, \
    GetMethodRequestData, GetMethodResponseData, UpdateBalanceMethodRequestData, UpdateBalanceMethodResponseData, \
    AddToMethodBalanceRequestData, AddToMethodBalanceResponseData, UpdatePositionMethodRequestData, \
    UpdatePositionMethodResponseData, DeleteMethodRequestData, DeleteMethodResponseData, \
    StartStopPaymentMethodRequestData, StartStopPaymentMethodResponseData
from .base import Router


class MethodRouter(Router):
    prefix = '/methods'

    @route(
        path='/create',
        request_data=CreateMethodRequestData,
        response_data=CreateMethodResponseData,
        func=MethodFacadeService().create,
        response_field='method',
    )
    async def create(self):
        pass

    @route(
        path='/get-all',
        request_data=GetMethodsRequestData,
        response_data=GetMethodsResponseData,
        func=MethodFacadeService().get_all,
        response_field='method',
    )
    async def get_all(self):
        pass

    @route(
        path='/get',
        request_data=GetMethodRequestData,
        response_data=GetMethodResponseData,
        func=MethodFacadeService().get,
        response_field='method',
    )
    async def get(self):
        pass

    @route(
        path='/update-balance',
        request_data=UpdateBalanceMethodRequestData,
        response_data=UpdateBalanceMethodResponseData,
        func=MethodFacadeService().update_balance,
        response_field='method',
    )
    async def update_balance(self):
        pass

    @route(
        path='/add-to-balance',
        request_data=AddToMethodBalanceRequestData,
        response_data=AddToMethodBalanceResponseData,
        func=MethodFacadeService().add_to_balance,
    )
    async def add_to_balance(self):
        pass

    @route(
        path='/update-position',
        request_data=UpdatePositionMethodRequestData,
        response_data=UpdatePositionMethodResponseData,
        func=MethodFacadeService().update_position,
        response_field='method',
    )
    async def update_position(self):
        pass

    @route(
        path='/delete',
        request_data=DeleteMethodRequestData,
        response_data=DeleteMethodResponseData,
        func=MethodFacadeService().delete,
        response_field='method',
    )
    async def delete(self):
        pass

    @route(
        path='/start-payment',
        request_data=StartStopPaymentMethodRequestData,
        response_data=StartStopPaymentMethodResponseData,
        func=MethodFacadeService().start_payment,
        response_field='method',
    )
    async def start_payment(self):
        pass

    @route(
        path='/stop-payment',
        request_data=StartStopPaymentMethodRequestData,
        response_data=StartStopPaymentMethodResponseData,
        func=MethodFacadeService().stop_payment,
        response_field='method',
    )
    async def stop_payment(self):
        pass

==> yagroup_pay-0.1.4.tar.gz: yagroup_pay-0.1.4/yagroup_pay/routers/method.py <==
#
# (c) 2025, Yegor Yakubovich, yegoryakubovich.com, personal@yegoryakybovich.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from nexium_api import route

from yagroup_pay.shared import CreateMethodRequestData, CreateMethodResponseData, GetMethodsRequestData, GetMethodsResponseData, \
    GetMethodRequestData, GetMethodResponseData, UpdateBalanceMethodRequestData, UpdateBalanceMethodResponseData, \
    AddToMethodBalanceRequestData, AddToMethodBalanceResponseData, UpdatePositionMethodRequestData, \
    UpdatePositionMethodResponseData, DeleteMethodRequestData, DeleteMethodResponseData, \
    StartStopPaymentMethodRequestData, StartStopPaymentMethodResponseData
from .base import Router


class MethodRouter(Router):
    facade_service = 'MethodFacadeService'
    prefix = '/methods'

    @route(
        path='/create',
        request_data=CreateMethodRequestData,
        response_data=CreateMethodResponseData,
        response_field='method',
    )
    async def create(self):
        pass

    @route(
        path='/get-all',
        request_data=GetMethodsRequestData,
        response_data=GetMethodsResponseData,
        response_field='method',
    )
    async def get_all(self):
        pass

    @route(
        path='/get',
        request_data=GetMethodRequestData,
        response_data=GetMethodResponseData,
        response_field='method',
    )
    async def get(self):
        pass

    @route(
        path='/update-balance',
        request_data=UpdateBalanceMethodRequestData,
        response_data=UpdateBalanceMethodResponseData,
        response_field='method',
    )
    async def update_balance(self):
        pass

    @route(
        path='/add-to-balance',
        request_data=AddToMethodBalanceRequestData,
        response_data=AddToMethodBalanceResponseData,
    )
    async def add_to_balance(self):
        pass

    @route(
        path='/update-position',
        request_data=UpdatePositionMethodRequestData,
        response_data=UpdatePositionMethodResponseData,
        response_field='method',
    )
    async def update_position(self):
        pass

    @route(
        path='/delete',
        request_data=DeleteMethodRequestData,
        response_data=DeleteMethodResponseData,
        response_field='method',
    )
    async def delete(self):
        pass

    @route(
        path='/start-payment',
        request_data=StartStopPaymentMethodRequestData,
        response_data=StartStopPaymentMethodResponseData,
        response_field='method',
    )
    async def start_payment(self):
        pass

    @route(
        path='/stop-payment',
        request_data=StartStopPaymentMethodRequestData,
        response_data=StartStopPaymentMethodResponseData,
        response_field='method',
    )
    async def stop_payment(self):
        pass
